@@ -1,5 +1,5 @@
+from collections.abc import Generator
 from dataclasses import dataclass
-from typing import Generator
 
 from mypy.nodes import (
     Block,
@@ -59,6 +59,7 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "no-redundant-continue"
     code = 133
     msg: str = "Continue is redundant here"
     categories = ["control-flow", "readability"]
