@@ -1,5 +1,5 @@
+from collections.abc import Iterator
 from dataclasses import dataclass
-from typing import Iterator
 
 from mypy.nodes import (
     ArgKind,
@@ -51,6 +51,7 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "use-implicit-default"
     enabled = False
     code = 120
     msg: str = "Don't pass an argument if it is the same as the default value"
