@@ -1,6 +1,6 @@
 import re
 from collections.abc import Sequence
-from functools import cache
+from functools import cache, partial
 from importlib import metadata
 from io import StringIO
 from pathlib import Path
@@ -69,14 +69,16 @@ def get_source_lines(filepath: str) -> list[str]:
 def is_ignored_via_comment(error: Error) -> bool:
     assert error.filename
 
-    line = get_source_lines(error.filename)[error.line - 1]
+    line = get_source_lines(error.filename)[error.line - 1].rstrip()
 
-    if comment := re.search("# noqa(: [A-Z]{3,4}\\d{3})?$", line):
-        ignore = comment.group(1)
-        error_code = str(ErrorCode.from_error(type(error)))
+    if comment := re.search(r"""# noqa(: [^'"]*)?$""", line):
+        ignore = str(ErrorCode.from_error(type(error)))
+        error_codes = comment.group(1)
 
-        if not ignore or ignore[2:] == error_code:
-            return True
+        return not error_codes or any(
+            error_code == ignore
+            for error_code in error_codes[2:].replace(",", " ").split(" ")
+        )
 
     return False
 
@@ -175,16 +177,25 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
             for error in errors
             if not should_ignore_error(error, settings)
         ],
-        key=sort_errors,
+        key=partial(sort_errors, settings=settings),
     )
 
 
 def sort_errors(
-    error: Error | str,
-) -> tuple[str, int, int, str, int] | tuple[str, str]:
+    error: Error | str, settings: Settings
+) -> tuple[str | int, ...]:
     if isinstance(error, str):
         return ("", error)
 
+    if settings.sort_by == "error":
+        return (
+            error.prefix,
+            error.code,
+            error.filename or "",
+            error.line,
+            error.column,
+        )
+
     return (
         error.filename or "",
         error.line,
@@ -194,10 +205,32 @@ def sort_errors(
     )
 
 
-def format_errors(errors: Sequence[Error | str], quiet: bool) -> str:
-    done = "\n".join(str(error) for error in errors)
+def format_as_github_annotation(error: Error | str) -> str:
+    if isinstance(error, str):
+        return f"::error title=Refurb Error::{error}"
 
-    if not quiet and any(isinstance(error, Error) for error in errors):
+    assert error.filename
+
+    file = Path(error.filename).resolve().relative_to(Path.cwd())
+
+    return "::error " + ",".join(
+        [
+            f"line={error.line}",
+            f"col={error.column + 1}",
+            f"title=Refurb {error.prefix}{error.code}",
+            f"file={file}::{error.msg}",
+        ]
+    )
+
+
+def format_errors(errors: Sequence[Error | str], settings: Settings) -> str:
+    formatter = (
+        format_as_github_annotation if settings.format == "github" else str
+    )
+
+    done = "\n".join(formatter(error) for error in errors)  # type: ignore
+
+    if not settings.quiet and any(isinstance(err, Error) for err in errors):
         done += "\n\nRun `refurb --explain ERR` to further explain an error. Use `--quiet` to silence this message"
 
     return done
@@ -238,7 +271,7 @@ def main(args: list[str]) -> int:
         print(e)
         return 1
 
-    if formatted_errors := format_errors(errors, settings.quiet):
+    if formatted_errors := format_errors(errors, settings):
         print(formatted_errors)
 
     return 1 if errors else 0
