@@ -2,10 +2,10 @@ from __future__ import annotations
 
 import re
 import sys
-from collections.abc import Iterator
+from collections.abc import Callable, Iterator
 from dataclasses import dataclass, field, replace
 from pathlib import Path
-from typing import Any
+from typing import Any, Literal, TypeVar
 
 if sys.version_info >= (3, 11):
     import tomllib  # pragma: no cover
@@ -37,6 +37,8 @@ class Settings:
     config_file: str | None = None
     python_version: tuple[int, int] = get_python_version()
     mypy_args: list[str] = field(default_factory=list)
+    format: Literal["text", "github"] = "text"
+    sort_by: Literal["filename", "error"] = "filename"
 
     def __post_init__(self) -> None:
         if self.enable_all and self.disable_all:
@@ -75,6 +77,8 @@ class Settings:
             config_file=old.config_file or new.config_file,
             python_version=new.python_version,
             mypy_args=new.mypy_args or old.mypy_args,
+            format=new.format,
+            sort_by=new.sort_by,
         )
 
 
@@ -107,6 +111,20 @@ def parse_python_version(version: str) -> tuple[int, int]:
     raise ValueError("refurb: version must be in form `x.y`")
 
 
+def validate_format(format: str) -> Literal["github", "text"]:
+    if format in ("github", "text"):
+        return format  # type: ignore
+
+    raise ValueError(f'refurb: "{format}" is not a valid format')
+
+
+def validate_sort_by(sort_by: str) -> Literal["filename", "error"]:
+    if sort_by in ("filename", "error"):
+        return sort_by  # type: ignore
+
+    raise ValueError(f'refurb: cannot sort by "{sort_by}"')
+
+
 def parse_amend_error(err: str, path: Path) -> ErrorClassifier:
     classifier = parse_error_classifier(err)
 
@@ -132,6 +150,32 @@ def parse_amendment(  # type: ignore
     )
 
 
+T = TypeVar("T")
+
+
+def pop_type(  # type: ignore[misc]
+    ty: type[T], type_name: str = ""
+) -> Callable[..., T]:
+    def inner(  # type: ignore[misc]
+        config: dict[str, Any], name: str, *, default: T | None = None
+    ) -> T:
+        x = config.pop(name, default or ty())
+
+        if isinstance(x, ty):
+            return x
+
+        raise ValueError(
+            f'refurb: "{name}" must be a {type_name or ty.__name__}'
+        )
+
+    return inner
+
+
+pop_list = pop_type(list)
+pop_bool = pop_type(bool)
+pop_str = pop_type(str, "string")
+
+
 def parse_config_file(contents: str) -> Settings:
     tool = tomllib.loads(contents).get("tool")
 
@@ -143,38 +187,52 @@ def parse_config_file(contents: str) -> Settings:
     if not config:
         return Settings()
 
-    ignore = {parse_error_classifier(str(x)) for x in config.get("ignore", [])}
-    enable = {parse_error_classifier(str(x)) for x in config.get("enable", [])}
+    settings = Settings()
 
-    disable = {
-        parse_error_classifier(str(x)) for x in config.get("disable", [])
-    }
+    settings.load = pop_list(config, "load")
+    settings.quiet = pop_bool(config, "quiet")
+    settings.disable_all = pop_bool(config, "disable_all")
+    settings.enable_all = pop_bool(config, "enable_all")
 
-    version = config.get("python_version")
-    python_version = (
+    enable = pop_list(config, "enable")
+    disable = pop_list(config, "disable")
+    settings.enable = {parse_error_classifier(str(x)) for x in enable}
+    settings.disable = {parse_error_classifier(str(x)) for x in disable}
+    settings.enable -= settings.disable
+
+    ignore = pop_list(config, "ignore")
+    settings.ignore = {parse_error_classifier(str(x)) for x in ignore}
+
+    mypy_args = pop_list(config, "mypy_args")
+    settings.mypy_args = [str(x) for x in mypy_args]
+
+    version = pop_str(config, "python_version")
+    settings.python_version = (
         parse_python_version(version) if version else get_python_version()
     )
-    mypy_args = [str(arg) for arg in config.get("mypy_args", [])]
 
-    amendments: list[dict[str, Any]] = config.get("amend", [])  # type: ignore
+    settings.format = validate_format(
+        pop_str(config, "format", default="text")
+    )
+
+    settings.sort_by = validate_sort_by(
+        pop_str(config, "sort_by", default="filename")
+    )
+
+    amendments: list[dict[str, Any]] = config.pop("amend", [])  # type: ignore
 
     if not isinstance(amendments, list):
         raise ValueError('refurb: "amend" field(s) must be a TOML table')
 
     for amendment in amendments:
-        ignore.update(parse_amendment(amendment))
+        settings.ignore.update(parse_amendment(amendment))
 
-    return Settings(
-        ignore=ignore,
-        enable=enable - disable,
-        disable=disable,
-        load=config.get("load", []),
-        quiet=config.get("quiet", False),
-        disable_all=config.get("disable_all", False),
-        enable_all=config.get("enable_all", False),
-        python_version=python_version,
-        mypy_args=mypy_args,
-    )
+    if config:
+        raise ValueError(
+            f"refurb: unknown field(s): {', '.join(config.keys())}"
+        )
+
+    return settings
 
 
 def parse_command_line_args(args: list[str]) -> Settings:
@@ -249,6 +307,12 @@ def parse_command_line_args(args: list[str]) -> Settings:
 
             settings.python_version = parse_python_version(version)
 
+        elif arg == "--format":
+            settings.format = validate_format(get_next_arg(arg, iargs))
+
+        elif arg == "--sort":
+            settings.sort_by = validate_sort_by(get_next_arg(arg, iargs))
+
         elif arg == "--":
             settings.mypy_args = list(iargs)
 
